==> KleckFiles(2.17.0).zip: KleckFiles/html/Settings(remove).js <==
﻿// Site-wide Settings file "Settings.js"
//
// NOTE: To Disable simple rename Settings.js file to "Settings(example).js" 
//    or rename this func SETTINGS_RECORD() to something else so its not found.
// NOTE: everything after // is a comment (ignored by the program)
//
// Use SETTINGS_RECORD() to set a location for the 4 media types.
// 1. Set each to '' for the default location.
//    The 4 media buckets are 'video/', 'video_mp3/', 'radio/', 'shownotes/_data'
// 2. Use forward slashes '/' not backslash '\' in paths.
// 3. Paths must end with /'; eg. 'this.nnnn_data_path='yourpath/';
// 4. Path examples - all these work in Google Chrome. All point to the same location.
//    this.shownotes_data_path = 'file:///E:/shownotes/_data/';	
//    this.shownotes_data_path = 'E:/shownotes/_data/';	
//    this.shownotes_data_path = '../../../../shownotes/_data/';	
//    this.shownotes_data_path = '/shownotes/_data/';
//    this.shownotes_data_path = 'shownotes/_data/';   // which is same as default

function SETTINGS_RECORD() {   
  this.debug      = false;       // show debug info (used in shownotes)
  this.version    = "1.0";       // code version

  this.shownotes_data_path = '/KleckFiles.media/ShowNotes/_data/';	
  this.radio_data_path = '/KleckFiles.media/radio/';	
  this.video_data_path = '/KleckFiles.media/video/';	
  this.video_mp3_data_path = '/KleckFiles.media/video_mp3/';	
	
	
  // Ignore this section -- Inhouse code
  // basically this.FixPaths(); makes '/paths' root paths work in FireFox and Mac browsers
		
  // Win local file:///E:/index.html 
  // Mac local file:///Volumes/1TB-Kleck3/KleckFiles.media/index.html
  // Mac local file:///Users/freddy/Downloads/KleckFiles-3/index.html
	
  this.GetLocalDrive = function() 
  {
	 //example of local path 'file:///D:/path'.split('/')
	 // file:,,,D:,KleckFiles,scribe.html?210617 
	 var path = document.location.href.split('/');

	 if (path.length >= 5 && path[0] == 'file:' && path[1] == '' && path[2] == '') 
	 {
		 if (path[3].length == 2 && path[3].endsWith(':'))  // drive 'D:'
			 return 'file:///' + path[3]; // win 'files:///D:' 

		 if (path[3].toLowerCase() == "volumes") // mac file:///Volumes/ShareName
			 return 'file:///' + path[3] + '/' + path[4]; 
		 
		 if (path[3].toLowerCase() == "users")   // mac file:///Users/freddy
			 return 'file:///' + path[3] + '/' + path[4]; 		 
	 }
	 return '';
  }	
  
  // fix local root paths starting with / 
  this.FixPaths = function() {
    var drive = this.GetLocalDrive();  // eg '/E:'
	 if (drive) {
		 if (this.shownotes_data_path.startsWith('/'))
			  this.shownotes_data_path = drive + this.shownotes_data_path;
		 
		 if (this.radio_data_path.startsWith('/'))
			  this.radio_data_path = drive + this.radio_data_path;
		 
		 if (this.video_data_path.startsWith('/'))
			  this.video_data_path = drive + this.video_data_path;
		 
		 if (this.video_mp3_data_path.startsWith('/'))
			  this.video_mp3_data_path = drive + this.video_mp3_data_path;
	 }
  }
  this.FixPaths();
  
}







// KleckFiles/index.html startup customization settings.
// These settings probably not used anymore 

//__STARTUP__List1_CollapseAll=true;  // default is true. alt set false
//__STARTUP__List2_CollapseAll=true;  // default is true. alst set false

//__STARTUP__List1_Expand=["2011"];  //list of (lowercase!!) folders names to expand on startup eg ["2011", "2012", "2013"]
//__STARTUP__List2_Expand=[0, 1];    //list of playlists indexes to expand on startupeg. [0, 1, 5]

//__STARTUP__PAGETAB=1;           // Startup page -- 1=Videos 2=Playlists

//__SETUP__WEBUNLOCKKEY="";       // In house use -- Web Unlock security Key

//== These 2 No longer used ==
//__STARTUP__YouTubeOverride=0;   // default =0 Set menu > Youtube =ON for web startup only. Set =1 force YouTube ON at startup. Set =2 set OFF at startup (see main menu)
//__STARTUP__ShowMsgBox=0;        // default =0 (program decides when to show startup message). Set=1 to always show. Set=2. Always hide on startup.

==> KleckFiles(3.03.1).zip: KleckFiles/html/Settings(remove).js <==
﻿// Site-wide Settings file "Settings.js"
//
// NOTE: To Disable simple rename Settings.js file to "Settings(example).js" 
//    or rename this func SETTINGS_RECORD() to something else so its not found.
// NOTE: everything after // is a comment (ignored by the program)
//
// Use SETTINGS_RECORD() to set a location for the 4 media types.
// 1. Set each to '' for the default location.
//    The 4 media buckets are 'video/', 'video_mp3/', 'radio/', 'shownotes/_data'
// 2. Use forward slashes '/' not backslash '\' in paths.
// 3. Paths must end with /'; eg. 'this.nnnn_data_path='yourpath/';
// 4. Path examples - all these work in Google Chrome. All point to the same location.
//    this.shownotes_data_path = 'file:///E:/shownotes/_data/';	
//    this.shownotes_data_path = 'E:/shownotes/_data/';	
//    this.shownotes_data_path = '../../../../shownotes/_data/';	
//    this.shownotes_data_path = '/shownotes/_data/';
//    this.shownotes_data_path = 'shownotes/_data/';   // which is same as default

function SETTINGS_RECORD() { 
  this.debug      = false;       // show debug info (used in shownotes)
  this.version    = "1.02";      // code version

  // 1.01 -- The /ShowNotes/ folder is all lowercase now - so /shownotes/
  // 1.02 -- added media_path - access to general root folder if extra content added

  this.media_path = '/KleckFiles.media/';
  this.shownotes_data_path = '/KleckFiles.media/shownotes/_data/';	
  this.radio_data_path     = '/KleckFiles.media/radio/';	
  this.video_data_path     = '/KleckFiles.media/video/';	
  this.video_mp3_data_path = '/KleckFiles.media/video_mp3/';	
 
	
	
  // Ignore this section -- Inhouse code
  // basically this.FixPaths(); makes '/paths' root paths work in FireFox and Mac browsers
		
  // Win local file:///E:/index.html 
  // Mac local file:///Volumes/1TB-Kleck3/KleckFiles.media/index.html
  // Mac local file:///Users/freddy/Downloads/KleckFiles-3/index.html
	
  this.GetLocalDrive = function() 
  {
	 //example of local path 'file:///D:/path'.split('/')
	 // file:,,,D:,KleckFiles,scribe.html?210617 
	 var path = document.location.href.split('/');

	 if (path.length >= 5 && path[0] == 'file:' && path[1] == '' && path[2] == '') 
	 {
		 if (path[3].length == 2 && path[3].endsWith(':'))  // drive 'D:'
			 return 'file:///' + path[3]; // win 'files:///D:' 

		 if (path[3].toLowerCase() == "volumes") // mac file:///Volumes/ShareName
			 return 'file:///' + path[3] + '/' + path[4]; 
		 
		 if (path[3].toLowerCase() == "users")   // mac file:///Users/freddy
			 return 'file:///' + path[3] + '/' + path[4]; 	
		 
		 if (path[3].length > 0)	             // Linux file:///media/mint/2TB KF Back/
          return 'file:///' + path[3] + '/' + path[4] + '/' + path[5]; 	 

	 }
	 return '';
  }	
  
  // fix local root paths starting with / 
  this.FixPaths = function() {
    var drive = this.GetLocalDrive();  // eg '/E:'
	 if (drive) {
		 if (this.media_path.startsWith('/'))
			  this.media_path = drive + this.media_path;

		 if (this.shownotes_data_path.startsWith('/'))
			  this.shownotes_data_path = drive + this.shownotes_data_path;
		 
		 if (this.radio_data_path.startsWith('/'))
			  this.radio_data_path = drive + this.radio_data_path;
		 
		 if (this.video_data_path.startsWith('/'))
			  this.video_data_path = drive + this.video_data_path;
		 
		 if (this.video_mp3_data_path.startsWith('/'))
			  this.video_mp3_data_path = drive + this.video_mp3_data_path;
	 }
  }
  this.FixPaths();
  
}







// KleckFiles/index.html startup customization settings.
// These settings probably not used anymore 

//__STARTUP__List1_CollapseAll=true;  // default is true. alt set false
//__STARTUP__List2_CollapseAll=true;  // default is true. alst set false

//__STARTUP__List1_Expand=["2011"];  //list of (lowercase!!) folders names to expand on startup eg ["2011", "2012", "2013"]
//__STARTUP__List2_Expand=[0, 1];    //list of playlists indexes to expand on startupeg. [0, 1, 5]

//__STARTUP__PAGETAB=1;           // Startup page -- 1=Videos 2=Playlists

//__SETUP__WEBUNLOCKKEY="";       // In house use -- Web Unlock security Key

//== These 2 No longer used ==
//__STARTUP__YouTubeOverride=0;   // default =0 Set menu > Youtube =ON for web startup only. Set =1 force YouTube ON at startup. Set =2 set OFF at startup (see main menu)
//__STARTUP__ShowMsgBox=0;        // default =0 (program decides when to show startup message). Set=1 to always show. Set=2. Always hide on startup.
